package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SysHolidayMapper;
import com.ruoyi.system.domain.SysHoliday;
import com.ruoyi.system.service.ISysHolidayService;

/**
 * 节假日，需每年手动更新Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-03-04
 */
@Service
public class SysHolidayServiceImpl implements ISysHolidayService 
{
    @Autowired
    private SysHolidayMapper sysHolidayMapper;

    /**
     * 查询节假日，需每年手动更新
     * 
     * @param id 节假日，需每年手动更新主键
     * @return 节假日，需每年手动更新
     */
    @Override
    public SysHoliday selectSysHolidayById(Long id)
    {
        return sysHolidayMapper.selectSysHolidayById(id);
    }

    /**
     * 查询节假日，需每年手动更新列表
     * 
     * @param sysHoliday 节假日，需每年手动更新
     * @return 节假日，需每年手动更新
     */
    @Override
    public List<SysHoliday> selectSysHolidayList(SysHoliday sysHoliday)
    {
        return sysHolidayMapper.selectSysHolidayList(sysHoliday);
    }

    /**
     * 新增节假日，需每年手动更新
     * 
     * @param sysHoliday 节假日，需每年手动更新
     * @return 结果
     */
    @Override
    public int insertSysHoliday(SysHoliday sysHoliday)
    {
        return sysHolidayMapper.insertSysHoliday(sysHoliday);
    }

    /**
     * 修改节假日，需每年手动更新
     * 
     * @param sysHoliday 节假日，需每年手动更新
     * @return 结果
     */
    @Override
    public int updateSysHoliday(SysHoliday sysHoliday)
    {
        return sysHolidayMapper.updateSysHoliday(sysHoliday);
    }

    /**
     * 批量删除节假日，需每年手动更新
     * 
     * @param ids 需要删除的节假日，需每年手动更新主键
     * @return 结果
     */
    @Override
    public int deleteSysHolidayByIds(Long[] ids)
    {
        return sysHolidayMapper.deleteSysHolidayByIds(ids);
    }

    /**
     * 删除节假日，需每年手动更新信息
     * 
     * @param id 节假日，需每年手动更新主键
     * @return 结果
     */
    @Override
    public int deleteSysHolidayById(Long id)
    {
        return sysHolidayMapper.deleteSysHolidayById(id);
    }
}
